@@ -350,7 +350,7 @@ class CreateDBInstanceHourRequest(AbstractModel):
         :type VpcId: str
         :param SubnetId: 私有网络下的子网ID，如果设置了 VpcId，则 SubnetId必填
         :type SubnetId: str
-        :param Password: 实例密码，不设置该参数则需要在创建完成后通过设置密码接口初始化实例密码。密码必须是8-16位字符，且至少包含字母、数字和字符 !@#%^*() 中的两种
+        :param Password: 实例密码，不设置该参数则默认密码规则为 实例ID+"@"+主账户uin。举例实例id为cmgo-higv73ed，uin为100000001，则默认密码为"cmgo-higv73ed@100000001"。密码必须是8-16位字符，且至少包含字母、数字和字符 !@#%^*() 中的两种
         :type Password: str
         :param ProjectId: 项目ID，不设置为默认项目
         :type ProjectId: int
@@ -465,7 +465,7 @@ class CreateDBInstanceRequest(AbstractModel):
         :type VpcId: str
         :param SubnetId: 私有网络下的子网 ID，如果设置了 UniqVpcId，则 UniqSubnetId 必填，请使用 查询子网列表
         :type SubnetId: str
-        :param Password: 实例密码，不设置该参数则需要在创建完成后通过设置密码接口初始化实例密码。密码必须是8-16位字符，且至少包含字母、数字和字符 !@#%^*() 中的两种
+        :param Password: 实例密码，不设置该参数则默认密码规则为 实例ID+"@"+主账户uin。举例实例id为cmgo-higv73ed，uin为100000001，则默认密码为"cmgo-higv73ed@100000001"。密码必须是8-16位字符，且至少包含字母、数字和字符 !@#%^*() 中的两种
         :type Password: str
         :param Tags: 实例标签信息
         :type Tags: list of TagInfo
@@ -762,9 +762,9 @@ class DescribeBackupDownloadTaskRequest(AbstractModel):
         :type InstanceId: str
         :param BackupName: 备份文件名，用来过滤指定文件的下载任务
         :type BackupName: str
-        :param StartTime: 指定要查询任务的时间范围，StartTime指定开始时间
+        :param StartTime: 指定要查询任务的时间范围，StartTime指定开始时间，不填默认不限制开始时间
         :type StartTime: str
-        :param EndTime: 指定要查询任务的时间范围，StartTime指定结束时间
+        :param EndTime: 指定要查询任务的时间范围，EndTime指定结束时间，不填默认不限制结束时间
         :type EndTime: str
         :param Limit: 此次查询返回的条数，取值范围为1-100，默认为20
         :type Limit: int
@@ -774,7 +774,7 @@ class DescribeBackupDownloadTaskRequest(AbstractModel):
         :type OrderBy: str
         :param OrderByType: 排序方式，取值为asc，desc两种，默认desc
         :type OrderByType: str
-        :param Status: 根据任务状态过滤。0-等待执行，1-正在下载，2-下载完成，3-下载失败，4-等待重试
+        :param Status: 根据任务状态过滤。0-等待执行，1-正在下载，2-下载完成，3-下载失败，4-等待重试。不填默认返回所有类型
         :type Status: list of int
         """
         self.InstanceId = None
@@ -2204,7 +2204,7 @@ class SpecItem(AbstractModel):
         :type SpecCode: str
         :param Status: 规格有效标志，取值：0-停止售卖，1-开放售卖
         :type Status: int
-        :param Cpu: 规格有效标志，取值：0-停止售卖，1-开放售卖
+        :param Cpu: 计算资源规格，单位为CPU核心数
         :type Cpu: int
         :param Memory: 内存规格，单位为MB
         :type Memory: int
